@@ -408,11 +408,13 @@ def downtmp_mktemp(capabilities, path, downtmp_prefix):
         )
         d = path
     else:
+        prev_mask = os.umask(0o022)
         d = check_exec(
             ["/bin/mktemp", "--directory", "--tmpdir", "autopkgtest.XXXXXX"],
             downp=True,
             outp=True,
         )
+        os.umask(prev_mask)
         check_exec(["/bin/chmod", mode, d], downp=True)
     if downtmp_prefix is not None:
         capabilities.append("downtmp-host=" + downtmp_prefix + d)
