@@ -361,6 +361,10 @@ class QemuSession:
                     # -cpu host is obviously not possible on a foreign
                     # CPU, -cpu max is unusably slow, but this works!
                     argv.extend(["-cpu", "cortex-a53"])
+            # Ubuntu Questing+ needs RVA23 baseline profile, so at
+            # least -cpu rva23s64.
+            if self.qemu_architecture == "riscv64":
+                argv.extend(["-cpu", "rva23s64"])
 
         argv.extend(
             [
